.. :changelog:

History
-------

0.5.0 (2015-09-12)
++++++++++++++++++

* Removed Django depemdemcy, mocked tests, Python 3.4 support

0.4.0 (2014-12-20)
++++++++++++++++++

* Zestimate extracted from Zillow's GetDeepSearchResults API.

0.3.1 (2014-12-20)
++++++++++++++++++

* Added test cases and increased test coverage setup.

0.3.0 (2014-12-19)
++++++++++++++++++

* Refactored structure, travis CI compliance, coverage setup.

0.2.7
++++++++++++++++++

* Bug fix: Missing ParseError, numRooms now read from UpdatedProperty

0.2.6
++++++++++++++++++

* Bug fix

0.2.5
++++++++++++++++++

* Using markdown as README file for setup.py

0.2.4
++++++++++++++++++

* Coordinates provides as GEOS point

0.2.3
++++++++++++++++++

* New attributes added: home_description, num_floors, floor_material, parking_type

0.2.2
++++++++++++++++++

* Licence changed to MIT

0.2.1
++++++++++++++++++

* pip created and code refactured

0.2
++++++++++++++++++

* API Wrapper for the GetDeepSearchResults and GetUpdatedPropertyDetails API. test.py and setup.py created.

0.1
++++++++++++++++++

* Project created